#ifndef ULTRA_CP_
#define ULTRA_CP_

#include <dirent.h>
#include <libgen.h>
#include <linux/limits.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <time.h>
#include <unistd.h>
#include <utime.h>

/**
 * @brief Get the given file permissions
 *
 * @param name Path of the file
 *
 * @returns Permissions string
 */
char *get_permissions(const char *name);

/**
 * @brief Get the given file size
 *
 * @param name Path of the file
 *
 * @returns File size
 */
int get_size(const char *name);

/**
 * @brief Get the given file date
 *
 * @param name Path of the file
 *
 * @returns File date
 */
char *get_date(const char *name);

/**
 * @brief List the content of the given directory
 *
 * @param name Relative path
 */
void list_dir(const char *name);

/**
 * @brief Copy all content from sources to destination
 *
 * @param sources List of all sources to copy
 * @param destination Destination for the content
 * @param options Copy options
 * @param source_count Source count
 */
void copy_files(const char **sources, const char *destination, uint8_t options,
                int source_count);
#endif // !ULTRA_CP_
